@@ -22,7 +22,7 @@ class MultiProcess(events.Plugin):
     configSection = 'multiprocess'
 
     def __init__(self):
-        self.addArgument(self.setProcs, 'N', 'processes', '# o procs')
+        self.addArgument(self.setProcs, 'N', 'processes', 'Number of processes used to run tests (0 = auto)')
         self.testRunTimeout = self.config.as_float('test-run-timeout', 60.0)
         self._procs = self.config.as_int(
             'processes', 0)
@@ -46,7 +46,7 @@ class MultiProcess(events.Plugin):
     def procs(self, value):
         """Setter for procs property"""
         if value < 0:
-            raise AttributeError("Can't set the procs number to less than 0, (0 = Auto)")
+            raise ValueError("Number of processes cannot be less than 0")
         self._procs = value
 
     def setProcs(self, num):
@@ -62,7 +62,7 @@ class MultiProcess(events.Plugin):
         #Background:  On Windows, select.select only works on sockets.  So the
         #ability to select a bindable address and optionally port for the mp
         #plugin was added.  Pipes should support a form of select, but this
-        #would require using pywin32.  There are altnernatives but all have
+        #would require using pywin32.  There are alternatives but all have
         #some kind of downside.  An alternative might be creating a connection
         #like object using a shared queue for incomings events. 
         self.bind_host = None
@@ -274,6 +274,14 @@ class MultiProcess(events.Plugin):
                     'test_not_found',
                     RuntimeError("Unable to locate test case for %s in "
                                  "main process" % event.test))._tests[0]
+            # subtest support
+            if 'subtest' in event.metadata:
+                message, params = event.metadata.pop('subtest')
+                # XXX the sentinel value does not survive the pickle
+                # round-trip and must be reset by hand
+                if type(message) == type(object()):
+                    message = unittest.case._subtest_msg_sentinel
+                event.test = unittest.case._SubTest(event.test, message, params)
 
     def _exportSession(self):
         """
